pub fn storage_service_test_endpoint() -> Result<String, StorageServiceStoreError>Expand description
Returns the storage service endpoint used for testing, read from the environment.
pub fn storage_service_test_endpoint() -> Result<String, StorageServiceStoreError>Returns the storage service endpoint used for testing, read from the environment.